summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2022-03-23 17:40:33 +0000
committerMichael Drake <tlsa@netsurf-browser.org>2022-03-23 17:49:25 +0000
commit508160b28de4899bb86b5ca14616f01e58196e1c (patch)
treef4d0da4e38e6b5415c57ad11a34da2e427616a7a /include
parent617da7327f1247ae6930a814e065531a08cde4b5 (diff)
downloadlibnsgif-508160b28de4899bb86b5ca14616f01e58196e1c.tar.gz
API: GIF: Take client colour layout on nsgif_create().
Map the requested layout to appropriate pixel channel offsets.
Diffstat (limited to 'include')
-rw-r--r--include/nsgif.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/include/nsgif.h b/include/nsgif.h
index 5fcb608..655486b 100644
--- a/include/nsgif.h
+++ b/include/nsgif.h
@@ -231,13 +231,15 @@ const char *nsgif_strerror(nsgif_error err);
/**
* Create the NSGIF object.
*
* \param[in] bitmap_vt Bitmap operation functions v-table.
* \param[out] gif_out Return \ref nsgif_t object on success.
*
* \return NSGIF_OK on success, or appropriate error otherwise.
*/
nsgif_error nsgif_create(
const nsgif_bitmap_cb_vt *bitmap_vt,
+ nsgif_bitmap_fmt_t bitmap_fmt,
nsgif_t **gif_out);
/**
@@ -231,13 +231,15 @@ const char *nsgif_strerror(nsgif_error err);
* Create the NSGIF object.
*
- * \param[in] bitmap_vt Bitmap operation functions v-table.
- * \param[out] gif_out Return \ref nsgif_t object on success.
+ * \param[in] bitmap_vt Bitmap operation functions v-table.
+ * \param[in] bitmap_fmt Bitmap pixel format specification.
+ * \param[out] gif_out Return \ref nsgif_t object on success.
*
* \return NSGIF_OK on success, or appropriate error otherwise.